==> smpl_io-1.0.6.tar.gz: smpl_io-1.0.6/README.md <==
# smpl_io
Simplified plotting and fitting in python.

[![PyPI version][pypi image]][pypi link] [![PyPI version][pypi versions]][pypi link]  ![downloads](https://img.shields.io/pypi/dm/smpl_io.svg)

[![test][a t image]][a t link]     [![Coverage Status][c t i]][c t l]  [![Documentation][rtd t i]][rtd t l]|

## Documentation

-   <https://apn-pucky.github.io/smpl_io/index.html>

## Versions

### Stable

```sh
pip install smpl_io
```

Optional: --user or --upgrade

### Dev

```sh
pip install --index-url https://test.pypi.org/simple/ smpl_io
```

[doc stable]: https://apn-pucky.github.io/smpl_io/index.html
[doc test]: https://apn-pucky.github.io/smpl_io/test/index.html

[pypi image]: https://badge.fury.io/py/smpl_io.svg
[pypi link]: https://pypi.org/project/smpl_io/
[pypi versions]: https://img.shields.io/pypi/pyversions/smpl_io.svg

[a s image]: https://github.com/APN-Pucky/smpl_io/actions/workflows/stable.yml/badge.svg
[a s link]: https://github.com/APN-Pucky/smpl_io/actions/workflows/stable.yml
[a t link]: https://github.com/APN-Pucky/smpl_io/actions/workflows/test.yml
[a t image]: https://github.com/APN-Pucky/smpl_io/actions/workflows/test.yml/badge.svg

[cc s q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s q l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade?branch=stable
[cc s c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s c l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage?branch=stable

[cc q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2
[cc q l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl&amp;utm_campaign=Badge_Grade
[cc c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2
[cc c l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl&utm_campaign=Badge_Coverage

[c s i]: https://coveralls.io/repos/github/APN-Pucky/smpl_io/badge.svg?branch=stable
[c s l]: https://coveralls.io/github/APN-Pucky/smpl_io?branch=stable
[c t l]: https://coveralls.io/github/APN-Pucky/smpl_io?branch=master
[c t i]: https://coveralls.io/repos/github/APN-Pucky/smpl_io/badge.svg?branch=master

[rtd s i]: https://readthedocs.org/projects/smpl_io/badge/?version=stable
[rtd s l]: https://smpl_io.readthedocs.io/en/stable/?badge=stable
[rtd t i]: https://readthedocs.org/projects/smpl_io/badge/?version=latest
[rtd t l]: https://smpl_io.readthedocs.io/en/latest/?badge=latest

==> smpl_io-1.1.0.tar.gz: smpl_io-1.1.0/README.md <==
# smpl_io
Simplified plotting and fitting in python.

[![PyPI version][pypi image]][pypi link] [![PyPI version][pypi versions]][pypi link]  ![downloads](https://img.shields.io/pypi/dm/smpl_io.svg)

[![test][a t image]][a t link]     [![Coverage Status][c t i]][c t l] 

## Documentation

-   <https://apn-pucky.github.io/smpl_io/index.html>

## Versions

### Stable

```sh
pip install smpl_io
```

Optional: --user or --upgrade

### Dev

```sh
pip install --index-url https://test.pypi.org/simple/ smpl_io
```

[doc stable]: https://apn-pucky.github.io/smpl_io/index.html
[doc test]: https://apn-pucky.github.io/smpl_io/test/index.html

[pypi image]: https://badge.fury.io/py/smpl_io.svg
[pypi link]: https://pypi.org/project/smpl_io/
[pypi versions]: https://img.shields.io/pypi/pyversions/smpl_io.svg

[a s image]: https://github.com/APN-Pucky/smpl_io/actions/workflows/stable.yml/badge.svg
[a s link]: https://github.com/APN-Pucky/smpl_io/actions/workflows/stable.yml
[a t link]: https://github.com/APN-Pucky/smpl_io/actions/workflows/test.yml
[a t image]: https://github.com/APN-Pucky/smpl_io/actions/workflows/test.yml/badge.svg

[cc s q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s q l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl_io&amp;utm_campaign=Badge_Grade?branch=stable
[cc s c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2?branch=stable
[cc s c l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl_io&utm_campaign=Badge_Coverage?branch=stable

[cc q i]: https://app.codacy.com/project/badge/Grade/38630d0063814027bd4d0ffaa73790a2
[cc q l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=APN-Pucky/smpl_io&amp;utm_campaign=Badge_Grade
[cc c i]: https://app.codacy.com/project/badge/Coverage/38630d0063814027bd4d0ffaa73790a2
[cc c l]: https://www.codacy.com/gh/APN-Pucky/smpl_io/dashboard?utm_source=github.com&utm_medium=referral&utm_content=APN-Pucky/smpl_io&utm_campaign=Badge_Coverage

[c s i]: https://coveralls.io/repos/github/APN-Pucky/smpl_io/badge.svg?branch=stable
[c s l]: https://coveralls.io/github/APN-Pucky/smpl_io?branch=stable
[c t l]: https://coveralls.io/github/APN-Pucky/smpl_io?branch=master
[c t i]: https://coveralls.io/repos/github/APN-Pucky/smpl_io/badge.svg?branch=master

[rtd s i]: https://readthedocs.org/projects/smpl_io/badge/?version=stable
[rtd s l]: https://smpl_io.readthedocs.io/en/stable/?badge=stable
[rtd t i]: https://readthedocs.org/projects/smpl_io/badge/?version=latest
[rtd t l]: https://smpl_io.readthedocs.io/en/latest/?badge=latest
